# sha256sumf

A simple command line utility for producing recursive SHA 256 checksums of folders using:

* Inner file contents
* Inner file paths 
* Inner folder paths

Produces the same output as sha256sum when used with a single file.